#!/usr/bin/python
# -*- encoding: utf-8 -*-


import serial     # doplnek pro seriovou komunikaci
import time       


# nastaveni seriove komunikace s GPS modulem
spojeni = serial.Serial(port='/dev/ttyAMA0',          # Pripojeni na GPIO konektor na piny TxD a RxD 
                        baudrate=9600,                # rychlost 9600
                        bytesize=serial.EIGHTBITS,    # 8 bitu dat
                        parity=serial.PARITY_NONE,    # bez paritniho bitu
                        stopbits=serial.STOPBITS_ONE, # 1 stop bit
                        timeout=None,
                        xonxoff=False,
                        rtscts=False,
                        writeTimeout=None,
                        dsrdtr=False,
                        interCharTimeout=None)


while True:     # nepretrzite zjistovani souradnic

  msgid = ""
  # z GPS modulu se ctou ruzne zpravy, ale program zajima jen zprava, zacinajici pismeny "$GPGGA"
  while (msgid != "$GPGGA"):    
    zprava = spojeni.readline()  # vsechny zpravy se ctou z komunikacni linky po radkach (1 radka = 1 zprava)
    msgid = zprava[0:6]         
    
    
  slovo = zprava.split(",")  # rozlozeni GPGGA zpravy na jednotliva slova, ktera jsou oddelena carkami


  # slovo[6] obsahuje informaci o dostupnem signalu z druzice. Pokud obsahuje znak "1" nebo "2" je signal v poradku
  if (slovo[6] != "0"):   # kdyz je signal v poradku, zacni zpracovavat namerene udaje

    # v 1. slove je aktualni cas v GMT casovem pasmu
    # prekodovani GMT casu, ktery je vysilany druzicemi, do citelne podoby
    # priklad: slovo[1] = 152145.000 = 15hod. 21min. 45.000sek. = 15:21:45
    gmt_cas = slovo[1][0:2] + ":" + slovo[1][2:4] + ":"   + slovo[1][4:6]


    # ve 2. a 4. slove jsou aktualni souradnice
    # prepocet namerenych hodnot (stupne, minuty a desetiny minut) na stupne
    #               priklad : slovo[2] = "4926.66215" = 49 stupnu 26.66215 minut = 49.4443691667 stupnu
    lat_mer = float(slovo[2][0:2]) + (float(slovo[2][2:11]) / 60.0) 
    lon_mer = float(slovo[4][0:3]) + (float(slovo[4][3:12]) / 60.0) 
  

    satelity = slovo[7]   # v 7. slove je pocet komunikujicich satelitu
    altitude = slovo[9]   # v 9. slove je nadmorska vyska
    
    # slovo[3] obsahuje znak N nebo S pro severni nebo jizni sirku
    # slovo[5] obsahuje znak W nebo E pro zapadni nebo vychodni delku
    print "Aktualni (zmerena) poloha: " , str(lat_mer) + slovo[3] , str(lon_mer) + slovo[5]
    print "Cas vysilany satelity [GMT]: " , gmt_cas 
    print "Pocet komunikujicich satelitu: " , satelity 
    print "Nadmorska vyska [m]: " , altitude
    print "-----------"



  else:   # pokud slovo[6] obsahuje znak "0", neni signal dostupny. V tom pripade se zobrazi jen neuplna zprava GPGGA
    print "Neni dostupny signal ze satelitu"
    print "GPGGA zprava: " , zprava        



  time.sleep(1)


spojeni.close()
